@@ -6,11 +6,10 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef KCALUTILS_VCALDRAG_H
-#define KCALUTILS_VCALDRAG_H
+#pragma once
 
 #include "kcalutils_export.h"
-#include <KCalendarCore/MemoryCalendar>
+#include <KCalendarCore/Calendar>
 
 class QMimeData;
 
@@ -34,8 +33,7 @@ Q_REQUIRED_RESULT KCALUTILS_EXPORT bool canDecode(const QMimeData *);
 /**
   Decode drag&drop object to vCalendar component \a vcal.
 */
-Q_REQUIRED_RESULT KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalendarCore::MemoryCalendar::Ptr &cal);
+Q_REQUIRED_RESULT KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalendarCore::Calendar::Ptr &cal);
 }
 }
 
-#endif
